@@ -44,14 +44,14 @@ import pandas as pd
 #
 # fig = df.iplot('distplot', asFigure=True)
 # st.plotly_chart(fig, use_container_width=True)
-
-# pandas plotly_chart
-import cufflinks as cf
-
-cf.set_config_file(offline=True)
-
-fig = pd.DataFrame(range(10)).iplot(asFigure=True)
-st.plotly_chart(fig, use_container_width=True)
+#
+# # pandas plotly_chart
+# import cufflinks as cf
+#
+# cf.set_config_file(offline=True)
+#
+# fig = pd.DataFrame(range(10)).iplot(asFigure=True)
+# st.plotly_chart(fig, use_container_width=True)
 ''' _This_ is some __Markdown__ '''
 
 
