@@ -23,7 +23,7 @@ class Cut(Executor):
     @requests(on='/cut')
     async def add_text(self, docs: DocumentArray, **kwargs):
         for d in docs:
-            d.tensor = jieba.lcut(d.text)
+            d.text = jieba.lcut(d.text)
 
 
 # f = Flow(port=9955).add(uses=MyExec).add(uses=Exec)
