@@ -9,11 +9,11 @@
 # # @Description  :
 #
 #
-# from meutils.pipe import *
-# from appzoo import App
-#
-# app = App()
-# app_ = app.app
+from meutils.pipe import *
+from appzoo import App
+
+app = App()
+app_ = app.app
 #
 #
 # # app.add_route('/get', lambda **kwargs: kwargs, method="GET", result_key="GetResult")
@@ -31,16 +31,33 @@
 # #l;=]
 # #
 # # app.add_route_plus(proxy_app_, methods=["GET", "POST"], data=None)f j a
+
+import time
+
+logger.remove()
+
+# from asgiref.sync import sync_to_async
+# @sync_to_async(thread_sensitive=False)
+def sink(message):
+    time.sleep(3)  # IO processing...
+    print(message)
+
 #
-# import time
-#
-# def f(kwargs):
-#     return {'a': None, 'b': None, 'c': None, 't': pd.to_datetime('2022-08-03 10:06:45')}
-#
-# app.add_route_plus(f, methods=["GET", "POST"], data=None)
-#
-# if __name__ == '__main__':
-#     app.run(app.app_from(__file__), port=9955, debug=True)
+logger.add(sink, enqueue=True)
+# logger.add(sys.stdout, enqueue=True)
+
+
+def f(kwargs):
+    logger.info(1)
+    logger.info(2)
+    logger.info(3)
+
+    return {'a': None, 'b': None, 'c': None, 't': pd.to_datetime('2022-08-03 10:06:45')}
+
+app.add_route_plus(f, methods=["GET"], data=None)
+
+if __name__ == '__main__':
+    app.run(app.app_from(__file__), port=9955, debug=True)
 #
 #
 # from docarray import Document, DocumentArray
@@ -56,4 +73,3 @@
 # )
 #
 # print(q.matches[:5, ('text', 'scores__jaccard__value')])
-
