@@ -11,6 +11,7 @@
 
 from meutils.pipe import *
 from appzoo import App
+from meutils.str_utils import json_loads
 
 app = App()
 app_ = app.app
@@ -19,10 +20,17 @@ app_ = app.app
 @lru_cache()
 def post_func(kwargs: str):
     logger.info(kwargs)
-    return kwargs
+    return json_loads(kwargs)
 
 
-app.add_route_plus(post_func)
+@lru_cache()
+def post_func2(kwargs: tuple):  # 这个更快
+    logger.info(kwargs)
+    return dict(kwargs)
+
+
+app.add_route_plus(post_func, methods='GET')
+app.add_route_plus(post_func2, methods='GET')
 
 if __name__ == '__main__':
     app.run(app.app_from(__file__), port=9955, debug=True)
