@@ -14,7 +14,7 @@ from appzoo import App
 
 app = App()
 app_ = app.app
-app.config = yaml_load(get_resolve_path('wechat.yml', __file__))
+app.config = yaml.safe_load(get_resolve_path('wechat.yml', __file__).read_bytes())
 
 
 def appchat_send(kwargs):
@@ -25,16 +25,15 @@ def appchat_send(kwargs):
     kwargs = {**{'chat_id': 1162363786, 'msg_type': 'text', 'content': '这是一条测试信息'}, **kwargs}
     msg_type = kwargs.get('msg_type', 'text')
 
-    if msg_type == 'text':
-        wc.appchat.send(**kwargs)
-
-    elif msg_type in {'image', 'voice', 'file'}:
+    if msg_type in {'image', 'voice', 'file'}:
         for io in kwargs.pop('files'):
             kwargs['media_id'] = wc.media.upload(msg_type, io)['media_id']
-            wc.appchat.send(**kwargs)
+
+    wc.appchat.send(**kwargs)
 
     return kwargs
 
+
 app.add_route_plus(appchat_send, methods=['get', 'post'])
 
 if __name__ == '__main__':
